==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/HrefHintsGuidanceObject.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.HttpMethod;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * HrefHintsGuidanceObject
 */
@JsonPropertyOrder({ HrefHintsGuidanceObject.JSON_PROPERTY_ALLOW, HrefHintsGuidanceObject.JSON_PROPERTY_GUIDANCE })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class HrefHintsGuidanceObject implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ALLOW = "allow";
    private List<HttpMethod> allow = null;

    public static final String JSON_PROPERTY_GUIDANCE = "guidance";
    private List<String> guidance = null;

    public HrefHintsGuidanceObject() {
    }

    public HrefHintsGuidanceObject allow(List<HttpMethod> allow) {

        this.allow = allow;
        return this;
    }

    public HrefHintsGuidanceObject addallowItem(HttpMethod allowItem) {
        if (this.allow == null) {
            this.allow = new ArrayList<>();
        }
        this.allow.add(allowItem);
        return this;
    }

    /**
     * Get allow
     *
     * @return allow
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ALLOW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<HttpMethod> getAllow() {
        return allow;
    }

    @JsonProperty(JSON_PROPERTY_ALLOW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAllow(List<HttpMethod> allow) {
        this.allow = allow;
    }

    public HrefHintsGuidanceObject guidance(List<String> guidance) {

        this.guidance = guidance;
        return this;
    }

    public HrefHintsGuidanceObject addguidanceItem(String guidanceItem) {
        if (this.guidance == null) {
            this.guidance = new ArrayList<>();
        }
        this.guidance.add(guidanceItem);
        return this;
    }

    /**
     * Specifies the URI to invoke for granting scope consent required to complete the OAuth 2.0 connection
     *
     * @return guidance
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Specifies the URI to invoke for granting scope consent required to complete the OAuth 2.0 connection ")
    @JsonProperty(JSON_PROPERTY_GUIDANCE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<String> getGuidance() {
        return guidance;
    }

    @JsonProperty(JSON_PROPERTY_GUIDANCE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setGuidance(List<String> guidance) {
        this.guidance = guidance;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        HrefHintsGuidanceObject hrefHintsGuidanceObject = (HrefHintsGuidanceObject) o;
        return Objects.equals(this.allow, hrefHintsGuidanceObject.allow)
                && Objects.equals(this.guidance, hrefHintsGuidanceObject.guidance);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(allow, guidance);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class HrefHintsGuidanceObject {\n");
        sb.append("    allow: ").append(toIndentedString(allow)).append("\n");
        sb.append("    guidance: ").append(toIndentedString(guidance)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/HrefHintsGuidanceObject.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.HttpMethod;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * HrefHintsGuidanceObject
 */
@JsonPropertyOrder({ HrefHintsGuidanceObject.JSON_PROPERTY_ALLOW, HrefHintsGuidanceObject.JSON_PROPERTY_GUIDANCE })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class HrefHintsGuidanceObject implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ALLOW = "allow";
    private List<HttpMethod> allow = null;

    public static final String JSON_PROPERTY_GUIDANCE = "guidance";
    private List<String> guidance = null;

    public HrefHintsGuidanceObject() {
    }

    public HrefHintsGuidanceObject allow(List<HttpMethod> allow) {

        this.allow = allow;
        return this;
    }

    public HrefHintsGuidanceObject addallowItem(HttpMethod allowItem) {
        if (this.allow == null) {
            this.allow = new ArrayList<>();
        }
        this.allow.add(allowItem);
        return this;
    }

    /**
     * Get allow
     *
     * @return allow
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ALLOW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<HttpMethod> getAllow() {
        return allow;
    }

    @JsonProperty(JSON_PROPERTY_ALLOW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAllow(List<HttpMethod> allow) {
        this.allow = allow;
    }

    public HrefHintsGuidanceObject guidance(List<String> guidance) {

        this.guidance = guidance;
        return this;
    }

    public HrefHintsGuidanceObject addguidanceItem(String guidanceItem) {
        if (this.guidance == null) {
            this.guidance = new ArrayList<>();
        }
        this.guidance.add(guidanceItem);
        return this;
    }

    /**
     * Specifies the URI to invoke for granting scope consent required to complete the OAuth 2.0 connection
     *
     * @return guidance
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Specifies the URI to invoke for granting scope consent required to complete the OAuth 2.0 connection ")
    @JsonProperty(JSON_PROPERTY_GUIDANCE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<String> getGuidance() {
        return guidance;
    }

    @JsonProperty(JSON_PROPERTY_GUIDANCE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setGuidance(List<String> guidance) {
        this.guidance = guidance;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        HrefHintsGuidanceObject hrefHintsGuidanceObject = (HrefHintsGuidanceObject) o;
        return Objects.equals(this.allow, hrefHintsGuidanceObject.allow)
                && Objects.equals(this.guidance, hrefHintsGuidanceObject.guidance);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(allow, guidance);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class HrefHintsGuidanceObject {\n");
        sb.append("    allow: ").append(toIndentedString(allow)).append("\n");
        sb.append("    guidance: ").append(toIndentedString(guidance)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
